@@ -66,10 +66,8 @@ Megasync
 <screenshot></screenshot>
 
 <preinstall>
-echo "deb https://mega.nz/linux/MEGAsync/Debian_11/ ./">/etc/apt/sources.list.d/mxpitemp.list
-wget https://mega.nz/linux/MEGAsync/Debian_11/Release.key -O /tmp/megarelease.key
-apt-key add /tmp/megarelease.key
-rm /tmp/megarelease.key
+echo "deb https://mega.nz/linux/MEGAsync/Debian_testing/ ./">/etc/apt/sources.list.d/mxpitemp.list
+curl -sS https://mega.nz/linux/MEGAsync/Debian_testing/Release.key | gpg --dearmor --yes -o /etc/apt/trusted.gpg.d/megasync.gpg
 apt-get update
 </preinstall>
 
